import logging
from app.sensing_mgr.model_dev_base import ModelDevBase
from app.sensing_mgr.const import Const
from .reporters.environment_reporter import EnvironmentReporter


class ModelDevA6EBase(ModelDevBase):
    def __init__(self, modelConfig, cloud_config, send_cloud):
        super().__init__(modelConfig, send_cloud)
        self._env_reporter = None
        self._model_config = modelConfig
        self._cloud_config = cloud_config
        self._logging = logging.getLogger(Const.LOGGER_NAME)

    def on_recv_data(self, data):
        if data is None:
            self._logging.info("data from cloud is empty.")
            return

        if self._cloud_config:
            self._logging.info("update config from cloud.")
            self.update_reporter(self._model_config, data)
        else:
            self._logging.info("config don't update from cloud.")

        return

    def update_reporter(self, config, data):
        update_list = config.update_config(data)


        if not update_list:
            return

        for section, conf in update_list.items():
            if section == config.ENV_SENSOR:
                self._env_reporter.set_interval(conf.get(config.POLLING_INTERVAL))

    def send_interval(self, config):
        conf = config.get_default_conf()
        return conf.get(config.SEND_INTERVAL)

    def _make_active_reporters(self, config, report_queue, report_repository):
        reporters = []
        return reporters

    def _make_reporters(self, config):
        # hide super()'s CpuTempReporter
        reporters = []
        conf = config.get_env_sensor_conf()
        env_reporter = EnvironmentReporter()
        env_reporter.set_interval(conf.get(config.POLLING_INTERVAL))
        reporters.append(env_reporter)
        self._env_reporter = env_reporter
        return reporters

#
# End of File
#
